# eric7.Plugins.VcsPlugins.vcsMercurial.QueuesExtension.HgQueuesRenamePatchDialog

Module implementing a dialog to enter the data to rename a patch.

### Global Attributes

None

### Classes

HgQueuesRenamePatchDialog | Class implementing a dialog to enter the data to rename a patch.

### Functions

None

## HgQueuesRenamePatchDialog

Class implementing a dialog to enter the data to rename a patch.

### Derived from

QDialog, Ui_HgQueuesRenamePatchDialog

### Class Attributes

None

### Class Methods

None

### Methods

HgQueuesRenamePatchDialog | Constructor
__updateUI | Private slot to update the UI.
getData | Public method to retrieve the entered data.
on_nameCombo_currentIndexChanged | Private slot to handle changes of the selected patch name.
on_nameEdit_textChanged | Private slot to handle changes of the new name.
on_namedButton_toggled | Private slot to handle changes of the selection method.

### Static Methods

None

#### HgQueuesRenamePatchDialog (Constructor)

HgQueuesRenamePatchDialog(currentPatch, patchesList, parent=None)

Constructor

currentPatch (str)
  name of the current patch
patchesList (list of str)
  list of patches to select from
parent (QWidget)
  reference to the parent widget

#### HgQueuesRenamePatchDialog.__updateUI

__updateUI()

Private slot to update the UI.

#### HgQueuesRenamePatchDialog.getData

getData()

Public method to retrieve the entered data.

Return:
  tuple of new name and selected patch

Return Type:
  tuple of (str, str)

#### HgQueuesRenamePatchDialog.on_nameCombo_currentIndexChanged

on_nameCombo_currentIndexChanged(_index)

Private slot to handle changes of the selected patch name.

_index (int)
  current index (unused)

#### HgQueuesRenamePatchDialog.on_nameEdit_textChanged

on_nameEdit_textChanged(_txt)

Private slot to handle changes of the new name.

_txt (str)
  text of the edit (unused)

#### HgQueuesRenamePatchDialog.on_namedButton_toggled

on_namedButton_toggled(_checked)

Private slot to handle changes of the selection method.

_checked (bool)
  state of the check box (unused)

Up